| Title: | The Extended Laplace Distribution |
|---|---|
| Description: | Provides computational tools for working with the Extended Laplace distribution, including the probability density function, cumulative distribution function, quantile function, random variate generation based on convolution with Uniform noise and the quantile-quantile plot. Useful for modeling contaminated Laplace data and other applications in robust statistics. See Saah and Kozubowski (2025) <doi:10.1016/j.cam.2025.116588>. |
| Authors: | David Saah [aut, cre] (ORCID: <https://orcid.org/0009-0006-8049-3627>), Tomasz Kozubowski [aut] |
| Maintainer: | David Saah <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.6 |
| Built: | 2026-05-24 09:35:05 UTC |
| Source: | https://github.com/saahdavid/extendedlaplace |
Density function of the Extended Laplace Distribution
dEL(y, mu, sigma, delta)dEL(y, mu, sigma, delta)
y |
Vector of values where the density is to be evaluated |
mu |
Location parameter |
sigma |
Scale parameter (must be > 0) |
delta |
Uniform noise parameter (must be > 0) |
Vector of density values
Saah, D. K., & Kozubowski, T. J. (2025). A new class of extended Laplace distributions with applications to modeling contaminated Laplace data. Journal of Computational and Applied Mathematics. doi:10.1016/j.cam.2025.116588
Cumulative Distribution Function of the Extended Laplace Distribution
pEL(y, mu, sigma, delta)pEL(y, mu, sigma, delta)
y |
Vector of values where the density is to be evaluated |
mu |
Location parameter |
sigma |
Scale parameter (must be > 0) |
delta |
Uniform noise parameter (must be > 0) |
Vector of distribution values
Saah, D. K., & Kozubowski, T. J. (2025). A new class of extended Laplace distributions with applications to modeling contaminated Laplace data. Journal of Computational and Applied Mathematics. doi:10.1016/j.cam.2025.116588
Inverse Cumulative Distribution Function or Quantile Function of the Extended Laplace Distribution
qEL(u, mu, sigma, delta)qEL(u, mu, sigma, delta)
u |
A numeric vector of probabilities. |
mu |
Location parameter |
sigma |
Scale parameter (must be > 0) |
delta |
Uniform noise parameter (must be > 0) |
Vector of quantiles values
Saah, D. K., & Kozubowski, T. J. (2025). A new class of extended Laplace distributions with applications to modeling contaminated Laplace data. Journal of Computational and Applied Mathematics. doi:10.1016/j.cam.2025.116588
Quantile-Quantile Plot for the Extended Laplace Distribution
qqplotEL(sample_data, mu, sigma, delta)qqplotEL(sample_data, mu, sigma, delta)
sample_data |
A numeric vector of sample data |
mu |
Location parameter |
sigma |
Scale parameter (must be > 0) |
delta |
Uniform noise parameter (must be > 0) |
A Q-Q plot comparing sample data to the theoretical Extended Laplace distribution
sample <- rEL(1000, mu = 0, sigma = 1, delta = 1) qqplotEL(sample, mu = 0, sigma = 1, delta = 1)sample <- rEL(1000, mu = 0, sigma = 1, delta = 1) qqplotEL(sample, mu = 0, sigma = 1, delta = 1)
Generates random samples from the Extended Laplace distribution using the convolution representation: , where and .
rEL(n, mu, sigma, delta)rEL(n, mu, sigma, delta)
n |
Integer. Sample size. |
mu |
Numeric. Location parameter. |
sigma |
Numeric. Scale parameter (must be > 0). |
delta |
Numeric. Uniform noise parameter (must be > 0). |
A numeric vector of random samples from the Extended Laplace distribution.
Saah, D. K., & Kozubowski, T. J. (2025). A new class of extended Laplace distributions with applications to modeling contaminated Laplace data. Journal of Computational and Applied Mathematics. doi:10.1016/j.cam.2025.116588
rEL(10, mu = 0, sigma = 1, delta = 0.5)rEL(10, mu = 0, sigma = 1, delta = 0.5)